@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.2.7 $
+// $Revision: 1.1.2.8 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
@@ -230,12 +230,15 @@ class XNPBookImportItemHandler extends XooNIpsImportItemHandler{
                 break;
             }
             
+            $cdata = $unicode->decode_utf8($this -> _cdata , xoonips_get_server_charset(),'h');
+            if ( trim( $cdata ) == '' ) {
+              break;
+            }
             $author_handler =& xoonips_getormhandler( 'xnpbook', 'author' );
             $authors =& $this -> _import_item ->getVar('author');
             $author=&$author_handler->create();
             
-            $author->set('author', $unicode->decode_utf8($this -> _cdata ,
-                                                         xoonips_get_server_charset(),'h'));
+            $author->set('author', $cdata );
             $author->set('author_order', 0);
             
             $authors[0] = $author;
@@ -244,13 +247,16 @@ class XNPBookImportItemHandler extends XooNIpsImportItemHandler{
             if( $this -> _detail_version != '1.03' ){
                 break;
             }
+            $cdata = $unicode->decode_utf8($this -> _cdata , xoonips_get_server_charset(),'h');
+            if ( trim( $cdata ) == '' ) {
+              break;
+            }
             $authors =& $this -> _import_item ->getVar('author');
             
             $author_handler =& xoonips_getormhandler( 'xnpbook', 'author' );
             $author=&$author_handler->create();
             
-            $author->set('author', $unicode->decode_utf8($this -> _cdata ,
-                                                         xoonips_get_server_charset(),'h'));
+            $author->set('author', $cdata );
             $author->set('author_order', count($authors));
             
             $authors[] = $author;
