@@ -1,5 +1,5 @@
 #
-# $Revision: 1.1 $
+# $Revision: 1.2 $
 #
 # Table structure for table `xnpfiles_item_detail`
 #
@@ -10,4 +10,4 @@ CREATE TABLE xnpfiles_item_detail (
   data_file_mimetype varchar(255),
   data_file_filetype varchar(255),
   PRIMARY KEY  (files_id)
-) TYPE=MyISAM;
+) TYPE=InnoDB;
