@@ -1,5 +1,5 @@
 #
-# $Revision: 1.1 $
+# $Revision: 1.2 $
 #
 # Table structure for table `xnpmemo_item_detail`
 #
@@ -8,4 +8,4 @@ CREATE TABLE xnpmemo_item_detail (
   memo_id int(10) unsigned NOT NULL,
   item_link varchar(255) default NULL,
   PRIMARY KEY  (memo_id)
-) TYPE=MyISAM;
+) TYPE=InnoDB;
