@@ -1,10 +1,10 @@
 <?php
-// $Id: menu.php,v 1.8 2006/08/30 06:43:35 makotonton Exp $
-//  ------------------------------------------------------------------------ //
-//                XOOPS - PHP Content Management System                      //
-//                    Copyright (c) 2000 XOOPS.org                           //
-//                       <http://www.xoops.org/>                             //
-//  ------------------------------------------------------------------------ //
+// $Revision: 1.8.4.1.2.2 $
+// ------------------------------------------------------------------------- //
+//  XooNIps - Neuroinformatics Base Platform System                          //
+//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  http://xoonips.sourceforge.jp/                                           //
+// ------------------------------------------------------------------------- //
 //  This program is free software; you can redistribute it and/or modify     //
 //  it under the terms of the GNU General Public License as published by     //
 //  the Free Software Foundation; either version 2 of the License, or        //
@@ -23,24 +23,12 @@
 //  You should have received a copy of the GNU General Public License        //
 //  along with this program; if not, write to the Free Software              //
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
-//  ------------------------------------------------------------------------ //
-
+// ------------------------------------------------------------------------- //
+$adminmenu[0]['title'] = _MI_XOONIPS_ADMENU1;
+$adminmenu[0]['link'] = 'admin/system.php';
 $adminmenu[1]['title'] = _MI_XOONIPS_ADMENU2;
-$adminmenu[1]['link'] = "admin/useradmin.php";
+$adminmenu[1]['link'] = 'admin/policy.php';
 $adminmenu[2]['title'] = _MI_XOONIPS_ADMENU3;
-$adminmenu[2]['link'] = "admin/config.php";
-$adminmenu[3]['title'] = _MI_XOONIPS_ADMENU4;
-$adminmenu[3]['link'] = "admin/pickup.php";
-$adminmenu[4]['title'] = _MI_XOONIPS_ADMENU5;
-$adminmenu[4]['link'] = "admin/oaipmh.php";
-$adminmenu[5]['title'] = _MI_XOONIPS_ADMENU6;
-$adminmenu[5]['link'] = "admin/filesearch.php";
-$adminmenu[6]['title'] = _MI_XOONIPS_ADMENU7;
-$adminmenu[6]['link'] = "admin/posi_order.php";
-$adminmenu[7]['title'] = _MI_XOONIPS_ADMENU8;
-$adminmenu[7]['link'] = "admin/ranking.php";
-$adminmenu[8]['title'] = _MI_XOONIPS_ADMENU9;
-$adminmenu[8]['link'] = "admin/ranking_log.php";
-$adminmenu[9]['title'] = _MI_XOONIPS_ADMENU10;
-$adminmenu[9]['link'] = "admin/itemtype_order.php";
-?>
\ No newline at end of file
+$adminmenu[2]['link'] = 'admin/maintenance.php';
+
+?>
