@@ -1,37 +1,47 @@
 <?php
-//  $Revision: 1.11.2.1 $                                                           //
-//  --------------------------------------------------------------------------  //
-//  XooNIps Xoops modules for Neuroinformatics Platforms                        //
-//  Copyright (C) 2005 RIKEN, Japan. All rights reserved.                       //
-//  http://sourceforge.jp/projects/xoonips/                                     //
-//  --------------------------------------------------------------------------  //
-//  This program is free software; you can redistribute it and/or               //
-//  modify it under the terms of the GNU General Public License                 //
-//  as published by the Free Software Foundation; either version 2              //
-//  of the License, or (at your option) any later version.                      //
-//                                                                              //
-//  This program is distributed in the hope that it will be useful,             //
-//  but WITHOUT ANY WARRANTY; without even the implied warranty of              //
-//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               //
-//  GNU General Public License for more details.                                //
-//                                                                              //
-//  You should have received a copy of the GNU General Public License           //
-//  along with this program; if not, write to the Free Software                 //
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. //
-//  --------------------------------------------------------------------------  //
-
+// $Revision: 1.12.2.1.2.10 $
+// ------------------------------------------------------------------------- //
+//  XooNIps - Neuroinformatics Base Platform System                          //
+//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  http://xoonips.sourceforge.jp/                                           //
+// ------------------------------------------------------------------------- //
+//  This program is free software; you can redistribute it and/or modify     //
+//  it under the terms of the GNU General Public License as published by     //
+//  the Free Software Foundation; either version 2 of the License, or        //
+//  (at your option) any later version.                                      //
+//                                                                           //
+//  You may not change or alter any portion of this comment or credits       //
+//  of supporting developers from this source code or any supporting         //
+//  source code which is considered copyrighted (c) material of the          //
+//  original comment or credit authors.                                      //
+//                                                                           //
+//  This program is distributed in the hope that it will be useful,          //
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
+//  GNU General Public License for more details.                             //
+//                                                                           //
+//  You should have received a copy of the GNU General Public License        //
+//  along with this program; if not, write to the Free Software              //
+//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
+// ------------------------------------------------------------------------- //
 $xoopsOption['pagetype'] = 'user';
-include '../../mainfile.php';
+include 'include/common.inc.php';
+include_once 'include/AL.php';
 include_once 'include/lib.php';
 
-// If not a user, redirect
-if ( !$xoopsUser ) {
-	redirect_header(XOOPS_URL.'/index.php',3,_MD_XOONIPS_ITEM_FORBIDDEN);
-	exit();
-    }
+xoonips_deny_guest_access();
 
 $uid = $_SESSION['xoopsUserId'];
 
+$textutil =& xoonips_getutility( 'text' );
+$formdata =& xoonips_getutility( 'formdata' );
+
+$pagen = $formdata->getValue( 'post', 'pagen', 'i', false );
+$page_num_post = $formdata->getValue( 'post', 'page_num', 'i', false);
+$pass_pages = $formdata->getValueArray( 'post', 'pass_pages', 's', false );
+$checkons_post = $formdata->getValueArray( 'post', 'checkons', 's', false );
+$changeButton = $formdata->getValue( 'post', 'changeButton', 'b', false );
+$show_item_check = $formdata->getValueArray( 'post', 'show_item_check', 's', false );
 
 // Page number optimization
 function page_optimize($page, $last){
@@ -114,45 +124,41 @@ while($row = $xoopsDB->fetchArray($res)){
 
 
 $xoopsOption['template_main'] = 'xoonips_editshowitem.html';
-include './header.php';
+include XOOPS_ROOT_PATH.'/header.php';
 
 
-// $_POST['page_num']: page number on page that had been displayed ahead
-$myts =& MyTextSanitizer::getInstance();
-if( isset( $_POST['page_num'] ) ){
-	$bepage = intval( $_POST['page_num'] );
+// $page_num_post: page number on page that had been displayed ahead
+if( isset( $page_num_post ) ){
+	$bepage = $page_num_post;
 } else {
 	$bepage = '';
 }
 
-if( isset( $_POST['show_item_check'] ) ){
-	if( isset( $_POST['checkons'] ) ) {
-		foreach( $_POST['checkons'] as $ckey => $cvalue ){
+if( isset( $show_item_check ) ){
+    $pre_show = array();
+	if( isset( $checkons_post ) ) {
+		foreach( $checkons_post as $ckey => $cvalue ){
 			if( preg_match( "/,/", $cvalue ) !== 0 ) {
-				$chktmp = explode( ",", $myts->stripSlashesGPC( $cvalue ) );
+				$chktmp = explode( ",", $cvalue );
 				// $chktmps = array();
 				// $chktmps = array_merge($chktmps, $chktmp);
 			} else {
 				$chktmp = array( '0' => $cvalue );
 			}
-			if( isset( $pre_show ) ){
-				$pre_show = array_merge($pre_show, $chktmp);
-			} else {
-				$pre_show = $chktmp;
-			}
+			$pre_show = array_merge($pre_show, $chktmp);
 		// dump($pre_show);
 		}
-		$pre_show = array_merge( $pre_show, $_POST['show_item_check'] );
+		$pre_show = array_merge( $pre_show, $show_item_check );
 		// dump($pre_show);
 	} else {
-		$pre_show = $_POST['show_item_check'];
+		$pre_show = $show_item_check;
 	}
 	$pre_show = array_unique( $pre_show );
 	// dump($pre_show);
-} elseif( isset( $_POST['checkons'] ) ){
-	foreach( $_POST['checkons'] as $ckey => $cvalue ){
+} elseif( isset( $checkons_post ) ){
+	foreach( $checkons_post as $ckey => $cvalue ){
 		if( preg_match( "/,/", $cvalue ) !== 0 ) {
-			$chktmp = explode( ",", $myts->stripSlashesGPC( $cvalue ) );
+			$chktmp = explode( ",", $cvalue );
 			// echo "a";
 			// dump($chktmp);
 		} else {
@@ -201,7 +207,7 @@ if( isset( $pshow ) ){
 }
 
 // If changeButton is set, insert records into xoonips_item_show.
-if( isset( $_POST['changeButton'] ) ){
+if( isset( $changeButton ) ){
 	$tab_name = $xoopsDB->prefix('xoonips_item_show');
 	$sql = "SELECT item_id FROM $tab_name WHERE uid='". $uid ."'";
 	$res = $xoopsDB->query( $sql );
@@ -234,14 +240,14 @@ if( isset( $_POST['changeButton'] ) ){
 		$w_last = 1;
 		$w_check =1;
 	}
-	if( !isset( $_POST["pagen"] ) ) {
+	if( !isset( $pagen ) ) {
 		$w_page = page_optimize(1, $w_last);
 	}
-	else if( is_null($_POST["pagen"])){
+	else if( is_null($pagen)){
 		$w_page = page_optimize(1, $w_last);
 	}
-	else if( !is_null($_POST["pagen"])){
-		$w_page = page_optimize(intval( $_POST["pagen"] ), $w_last);
+	else if( !is_null($pagen)){
+		$w_page = page_optimize( $pagen, $w_last);
 	}
 	$w_offset = intval( ($w_page - 1) * 20 );
 	if( $w_offset < 0 ){
@@ -273,16 +279,16 @@ switch( $val ) {
 }
 
 
-if( isset( $_POST['checkons'] ) ){
-	foreach($_POST['checkons'] as $key => $value){
-		$cshow = explode( ",", $myts->stripSlashesGPC( $value ) );
+if( isset( $checkons_post ) ){
+	foreach($checkons_post as $key => $value){
+		$cshow = explode( ",", $value );
 	}
 } else {
-	$_POST['checkons'] = array();
+	$checkons_post = array();
 }
 
 
-if( !isset( $_POST['pass_pages'] ) || !is_array( $_POST['pass_pages'] ) ) {
+if( !isset( $pass_pages ) || !is_array( $pass_pages ) ) {
 	// echo "a";
 	$check = '';
 	$item_tmp = array();
@@ -295,7 +301,7 @@ if( !isset( $_POST['pass_pages'] ) || !is_array( $_POST['pass_pages'] ) ) {
 				$tsql = "SELECT display_name FROM ".$tab_name." WHERE item_type_id=".$ch_b."";
 				$tres = $xoopsDB->query($tsql);
 				$trow = $xoopsDB->fetchArray($tres);
-					$item_type_title = $myts->htmlSpecialChars($trow['display_name']);
+					$item_type_title = $textutil->html_special_chars($trow['display_name']);
 					$title_t = "<table><tr><th>".$item_type_title."</th></tr></table>";
 					$item_htmls[] = array( 'html'=>$title_t );
 			}
@@ -321,9 +327,9 @@ if( !isset( $_POST['pass_pages'] ) || !is_array( $_POST['pass_pages'] ) ) {
 			$ch_a = intval( $row["item_type_id"] );
 	}
 } else {
-	if( preg_match( "/,/", $_POST['pass_pages']['pass'] ) == 1 ) {
-		$passes = explode( ",", $myts->stripSlashesGPC( $_POST['pass_pages']['pass'] ) );
-		if( in_array( $_POST['pagen'], $passes ) ) {
+	if( preg_match( "/,/", $pass_pages['pass'] ) == 1 ) {
+		$passes = explode( ",", $pass_pages['pass'] );
+		if( in_array( $pagen, $passes ) ) {
 			$check = '';
 			if( isset($pshow) ){
 				$checkids = $pshow;
@@ -339,7 +345,7 @@ if( !isset( $_POST['pass_pages'] ) || !is_array( $_POST['pass_pages'] ) ) {
 				$tsql = "SELECT display_name FROM ".$tab_name." WHERE item_type_id=".$ch_b."";
 				$tres = $xoopsDB->query($tsql);
 				$trow = $xoopsDB->fetchArray($tres);
-					$item_type_title = $myts->htmlSpecialChars($trow['display_name']);
+					$item_type_title = $textutil->html_special_chars($trow['display_name']);
 					$title_t = "<table><tr><th>".$item_type_title."</th></tr></table>";
 					$item_htmls[] = array( 'html'=>$title_t );
 			}
@@ -387,7 +393,7 @@ if( !isset( $_POST['pass_pages'] ) || !is_array( $_POST['pass_pages'] ) ) {
 				$tsql = "SELECT display_name FROM ".$tab_name." WHERE item_type_id=".$ch_b."";
 				$tres = $xoopsDB->query($tsql);
 				$trow = $xoopsDB->fetchArray($tres);
-					$item_type_title = $myts->htmlSpecialChars($trow['display_name']);
+					$item_type_title = $textutil->html_special_chars($trow['display_name']);
 					$title_t = "<table><tr><th>".$item_type_title."</th></tr></table>";
 					$item_htmls[] = array( 'html'=>$title_t );
 			}
@@ -414,8 +420,8 @@ if( !isset( $_POST['pass_pages'] ) || !is_array( $_POST['pass_pages'] ) ) {
 			}
 		}
 	} else {
-		$passes = $myts->stripSlashesGPC( $_POST['pass_pages']['pass'] );
-		if( $_POST['pagen'] == $passes ) {
+		$passes = $pass_pages['pass'];
+		if( $pagen == $passes ) {
 			$check = '';
 			$checkids = $pshow;
 		$ch_a ='';
@@ -427,7 +433,7 @@ if( !isset( $_POST['pass_pages'] ) || !is_array( $_POST['pass_pages'] ) ) {
 				$tsql = "SELECT display_name FROM ".$tab_name." WHERE item_type_id=".$ch_b."";
 				$tres = $xoopsDB->query($tsql);
 				$trow = $xoopsDB->fetchArray($tres);
-					$item_type_title = $myts->htmlSpecialChars($trow['display_name']);
+					$item_type_title = $textutil->html_special_chars($trow['display_name']);
 					$title_t = "<table><tr><th>".$item_type_title."</th></tr></table>";
 					$item_htmls[] = array( 'html'=>$title_t );
 			}
@@ -465,13 +471,12 @@ if( !isset( $_POST['pass_pages'] ) || !is_array( $_POST['pass_pages'] ) ) {
 				$tsql = "SELECT display_name FROM ".$tab_name." WHERE item_type_id=".$ch_b."";
 				$tres = $xoopsDB->query($tsql);
 				$trow = $xoopsDB->fetchArray($tres);
-					$item_type_title = $myts->htmlSpecialChars($trow['display_name']);
+					$item_type_title = $textutil->html_special_chars($trow['display_name']);
 					$title_t = "<table><tr><th>".$item_type_title."</th></tr></table>";
 					$item_htmls[] = array( 'html'=>$title_t );
 			}
 					$check = intval( $row["item_id"] );
 					$item_tmp[] = $check;
-					// $csql = "SELECT item_id FROM ".$xoopsDB->prefix("xoonips_item_show")." where item_id=".$check." AND uid=".$uid." AND show_state='1'";
 					$csql = "SELECT item_id FROM ".$xoopsDB->prefix("xoonips_item_show")." where item_id=".$check." AND uid=".$uid."";
 					$cres = $xoopsDB->query($csql);
 					$crow = $xoopsDB->getRowsNum( $cres );
@@ -529,7 +534,7 @@ for( $i = $pages[0]+1; $i <= min(10, ceil( $sum_of_data / 20 ) ); $i++ ) {
 			}
 			break;
 		default:
-			$link ="&nbsp;<a href=\"javascript:void(0);\" onclick=\"action='#'; return mysubmit(".$pag.");\">".$pag."</a>&nbsp;";
+			$link ="&nbsp;<a href=\"#\" onclick=\"return xoonips_editshowitem_pagenavi(".$pag.");\">".$pag."</a>&nbsp;";
 	}
 	$w_link[] = array('link'=>$link);
 	}
@@ -557,8 +562,8 @@ if( $item_tmp ){
 	$xoopsTpl->assign('page_items', $page_items);
 }
 
-if( count( $_POST['checkons'] ) > 0 ) {
-	foreach( $_POST['checkons'] as $pokey => $povalue ){
+if( count( $checkons_post ) > 0 ) {
+	foreach( $checkons_post as $pokey => $povalue ){
 		$check_page = substr_count( $bepage, "x" );
 		switch ( $check_page ){
 			case 0:
@@ -573,7 +578,7 @@ if( count( $_POST['checkons'] ) > 0 ) {
 		// dump($bepage);
 		if( $pokey !== $bepage ){
 			$p_checkons[] = array( 'page'=>$pokey, 'checks'=>$povalue );
-		} elseif( !isset($_POST['show_item_check']) || count( $_POST['show_item_check'] ) == 0 ){
+		} elseif( !isset($show_item_check) || count( $show_item_check ) == 0 ){
 			$p_checkons[] = array( 'page'=>$bepage, 'checks'=>'nocheck' );
 		}
 	}
@@ -581,7 +586,7 @@ if( count( $_POST['checkons'] ) > 0 ) {
 	$p_checkons[] = array( 'page'=>'x'.$page_num, 'checks'=>'nocheck' );
 }
 // dump($p_checkons);
-if( isset( $_POST['show_item_check'] ) && count( $_POST['show_item_check'] ) !== 0 ){
+if( isset( $show_item_check ) && count( $show_item_check ) !== 0 ){
 	$check_page = substr_count( $bepage, "x" );
 	switch ( $check_page ){
 		case 0:
@@ -594,7 +599,7 @@ if( isset( $_POST['show_item_check'] ) && count( $_POST['show_item_check'] ) !==
 			$bepage = "x".$bepage;
 	}
 	// dump($bepage);
-	$checks = array($bepage => implode(",", $_POST['show_item_check']));
+	$checks = array($bepage => implode(",", $show_item_check));
 	// dump($checks);
 	foreach( $checks as $page => $checks ){
 		// $page = "x".$page;
@@ -644,9 +649,9 @@ if( isset( $_POST['show_item_check'] ) && count( $_POST['show_item_check'] ) !==
 		$checkons = $p_sicheck;
 	}
 	$xoopsTpl->assign('checkons', $checkons);
-} elseif( count( $_POST['checkons'] ) !== 0 ) {
+} elseif( count( $checkons_post ) !== 0 ) {
 	// echo "a";
-	foreach( $_POST['checkons'] as $page => $value ){
+	foreach( $checkons_post as $page => $value ){
 		if($page !== $bepage){
 			$checkons[] = array( 'page'=>$page, 'checks'=>$value );
 		} else {
@@ -655,8 +660,8 @@ if( isset( $_POST['show_item_check'] ) && count( $_POST['show_item_check'] ) !==
 	}
 	$xoopsTpl->assign('checkons', $checkons);
 } else {
-	if( isset( $_POST['pagen'] ) ){
-		$checkons[] = array('page'=>$_POST['pagen'], 'checks'=>'nocheck' );
+	if( isset( $pagen ) ){
+		$checkons[] = array('page'=>$pagen, 'checks'=>'nocheck' );
 	} else {
 		$checkons[] = array();
 	}
@@ -665,12 +670,12 @@ if( isset( $_POST['show_item_check'] ) && count( $_POST['show_item_check'] ) !==
 
 // passed pages
 if( isset( $page_num ) ) {
-	if( isset( $_POST['pass_pages'] ) ) {
-		if( strpos( $_POST['pass_pages']['pass'], "," ) === FALSE ){
-			$pre_pass = $myts->stripSlashesGPC( $_POST['pass_pages'] );
+	if( isset( $pass_pages ) ) {
+		if( strpos( $pass_pages['pass'], "," ) === FALSE ){
+			$pre_pass = $pass_pages;
 			array_push( $pre_pass, $page_num );
 		} else {
-			$pre_pass = explode( ",", $_POST['pass_pages']['pass'] );
+			$pre_pass = explode( ",", $pass_pages['pass'] );
 			$page_num = strval($page_num);
 			$pre_pass[] = $page_num;
 		}
@@ -682,6 +687,6 @@ if( isset( $page_num ) ) {
 	$xoopsTpl->assign( 'pass_pages', $pass_pages );
 }
 
-include "../../footer.php";
+include XOOPS_ROOT_PATH.'/footer.php';
 
 ?>
