@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.4.1.2.31 $
+// $Revision: 1.1.4.1.2.32 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
@@ -39,6 +39,9 @@ function xoonips_get_version() {
   $mydirname = basename( dirname( dirname( __FILE__ ) ) );
   $module_handler =& xoops_gethandler( 'module' );
   $module_obj =& $module_handler->getByDirname( $mydirname );
+  if ( ! is_object( $module_obj ) ) {
+    return 0;
+  }
   $version = intval( $module_obj->getVar( 'version', 'n' ) );
   return $version;
 }
