@@ -1,24 +1,30 @@
 <?php
-//  $Revision: 1.5 $                                                                  //
-//  --------------------------------------------------------------------------  //
-//  XooNIps Xoops modules for Neuroinformatics Platforms                        //
-//  Copyright (C) 2005 RIKEN, Japan. All rights reserved.                       //
-//  http://sourceforge.jp/projects/xoonips/                                     //
-//  --------------------------------------------------------------------------  //
-//  This program is free software; you can redistribute it and/or               //
-//  modify it under the terms of the GNU General Public License                 //
-//  as published by the Free Software Foundation; either version 2              //
-//  of the License, or (at your option) any later version.                      //
-//                                                                              //
-//  This program is distributed in the hope that it will be useful,             //
-//  but WITHOUT ANY WARRANTY; without even the implied warranty of              //
-//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               //
-//  GNU General Public License for more details.                                //
-//                                                                              //
-//  You should have received a copy of the GNU General Public License           //
-//  along with this program; if not, write to the Free Software                 //
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. //
-//  --------------------------------------------------------------------------  //
+// $Revision: 1.5.4.1.2.3 $
+// ------------------------------------------------------------------------- //
+//  XooNIps - Neuroinformatics Base Platform System                          //
+//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  http://xoonips.sourceforge.jp/                                           //
+// ------------------------------------------------------------------------- //
+//  This program is free software; you can redistribute it and/or modify     //
+//  it under the terms of the GNU General Public License as published by     //
+//  the Free Software Foundation; either version 2 of the License, or        //
+//  (at your option) any later version.                                      //
+//                                                                           //
+//  You may not change or alter any portion of this comment or credits       //
+//  of supporting developers from this source code or any supporting         //
+//  source code which is considered copyrighted (c) material of the          //
+//  original comment or credit authors.                                      //
+//                                                                           //
+//  This program is distributed in the hope that it will be useful,          //
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
+//  GNU General Public License for more details.                             //
+//                                                                           //
+//  You should have received a copy of the GNU General Public License        //
+//  along with this program; if not, write to the Free Software              //
+//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
+// ------------------------------------------------------------------------- //
+
 function
 filesize_private(  )
 {
@@ -43,6 +49,9 @@ filesize_group( $gid )
 function
 filesize_by_item_id( $iids )
 {
+	if ( count( $iids ) == 0 ) {
+		return 0;
+	}
 	$itemtypes = array(  );
 	if( xnp_get_item_types( $itemtypes ) != RES_OK ) {
 		return 0;
@@ -50,9 +59,7 @@ filesize_by_item_id( $iids )
 
 	$ret = 0.0;
 	foreach( $itemtypes as $i ) {
-		if( $i['item_type_id'] == ITID_INDEX
-			|| $i['item_type_id'] == ITID_BINDER )
-			continue;
+		if( $i['item_type_id'] == ITID_INDEX ) continue;
 		$modname = $i['name'];
 		global $xoopsDB;
 
@@ -130,15 +137,18 @@ check_private_item_storage_limit(  )
  */
 function available_space_of_group_item( $gid )
 {
-	$xnpsid = $_SESSION['XNPSID'];
-	$group = array(  );
-	if( xnp_get_group( $xnpsid, $gid, $group ) == RES_OK ) {
-		$iids = array(  );
-		if( xnp_get_group_item_id( $xnpsid, $gid, $iids ) == RES_OK ) {
-			return max( 0, $group['item_number_limit'] - count( $iids ) );
-		}
-	}
-	return 0;
+  $xg_handler =& xoonips_gethandler( 'xoonips', 'group' );
+  $xg_obj =& $xg_handler->getGroupObject( $gid );
+  if ( ! is_object( $xg_obj ) ) {
+    return 0;
+  }
+  $item_number_limit = $xg_obj->getVar( 'group_item_number_limit', 'n' );
+  $iids = array();
+  $xnpsid = $_SESSION['XNPSID'];
+  if( xnp_get_group_item_id( $xnpsid, $gid, $iids ) == RES_OK ) {
+	return max( 0, $item_number_limit - count( $iids ) );
+  }
+  return 0;
 }
 
 /**
@@ -152,13 +162,16 @@ function available_space_of_group_item( $gid )
 function
 check_group_item_storage_limit( $gid )
 {
-	$xnpsid = $_SESSION['XNPSID'];
-	$group = array(  );
-	if( xnp_get_group( $xnpsid, $gid, $group ) == RES_OK ) {
-		if( filesize_group( $gid ) >= $group['item_storage_limit'] ) {
-			return FALSE;
-		}
-	}
-	return TRUE;
+  $xg_handler =& xoonips_gethandler( 'xoonips', 'group' );
+  $xg_obj =& $xg_handler->getGroupObject( $gid );
+  if ( ! is_object( $xg_obj ) ) {
+    return false;
+  }
+  $item_storage_limit = $xg_obj->getVar( 'group_item_storage_limit', 'n' );
+  if ( filesize_group( $gid ) >= $item_storage_limit ) {
+    return false;
+  }
+  return true;
 }
+
 ?>
