@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.4.1.2.29 $
+// $Revision: 1.1.4.1.2.30 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
@@ -502,6 +502,9 @@ SQL;
     // remove obsolete configs
     xoonips_delete_obsolete_configs( 340 );
     break;
+  case 340:
+  default:
+    break;
   }
 
   // enable available notifications
