@@ -1,6 +1,31 @@
 <?php
+// $Revision: 1.4.8.2 $
+// ------------------------------------------------------------------------- //
+//  XooNIps - Neuroinformatics Base Platform System                          //
+//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  http://xoonips.sourceforge.jp/                                           //
+// ------------------------------------------------------------------------- //
+//  This program is free software; you can redistribute it and/or modify     //
+//  it under the terms of the GNU General Public License as published by     //
+//  the Free Software Foundation; either version 2 of the License, or        //
+//  (at your option) any later version.                                      //
+//                                                                           //
+//  You may not change or alter any portion of this comment or credits       //
+//  of supporting developers from this source code or any supporting         //
+//  source code which is considered copyrighted (c) material of the          //
+//  original comment or credit authors.                                      //
+//                                                                           //
+//  This program is distributed in the hope that it will be useful,          //
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
+//  GNU General Public License for more details.                             //
+//                                                                           //
+//  You should have received a copy of the GNU General Public License        //
+//  along with this program; if not, write to the Free Software              //
+//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
+// ------------------------------------------------------------------------- //
 /* constant strings
- * $Revision: 1.4 $
+ * $Revision: 1.4.8.2 $
  */
 
 // _MD_<MODULENAME>_<STRINGNAME>
@@ -90,7 +115,7 @@ define( '_MD_XOONIPS_METADATA_JUNII','
 10 : Presentation
 11 : Article
 12 : Learning Material
-20 : Data or database
+20 : Data or Dataset
 30 : Software
  */
 define( '_MD_XOONIPS_METADATA_JUNII2','
@@ -105,7 +130,7 @@ Preprint,/
 Presentation,
 Article,
 Learning Material,/
-Data or database,/
+Data or Dataset,/
 Software
 ');
 ?>
